@@ -6,16 +6,16 @@ use serde::{Deserialize, Serialize};
 pub struct User {
     /// The user's ID
     pub id: ID,
-    /// The user's GitHub username. Only visible to the user
-    pub github_id: Option<usize>,
+    /// The user's GitHub ID
+    pub github_id: usize,
     /// The user's username
     pub username: String,
-    /// The user's display name. Only visible to the user
+    /// The user's display name
     pub name: Option<String>,
-    /// The user's email. Only visible to the user
+    /// The user's email, only visible to the user
     pub email: Option<String>,
     /// A link to the user's avatar
-    pub avatar_url: Option<String>,
+    pub avatar_url: String,
     /// A description of the user
     pub bio: Option<String>,
     /// The time at which the user was created
@@ -28,13 +28,14 @@ pub struct User {
 #[serde(deny_unknown_fields)]
 pub struct TeamMember {
     /// The ID of the member's team
-    pub team_id: String,
+    pub team_id: ID,
     /// The user associated with the member
     pub user: User,
     /// This team member's role
     pub role: String,
-    /// The user's permissions in bitflag format (requires authorization to view)
-    /// 
+    /// The user's permissions in bitflag format
+    /// (requires authorization to view)
+    ///
     /// In order from first to eighth bit, the bits are:
     /// - UPLOAD_VERSION
     /// - DELETE_VERSION
@@ -45,7 +46,8 @@ pub struct TeamMember {
     /// - EDIT_MEMBER
     /// - DELETE_PROJECT
     pub permissions: Option<u8>,
-    /// Whether the user has accepted membership
+    /// Whether the user has accepted membership on the team
+    /// (requires authorization to view)
     pub accepted: bool,
 }
 
